function varargout=slicemesh(Th,P,varargin)
% FUNCTION slicemesh 
%   Plots the intersection of the plane defined by
%         P(1)*x+P(2)*y+P(3)*z+P(4)=0
%   and the siMesh object.
%
% USAGE
%   fc_siplt.slicemesh(Th,P) or slicemesh(Th,P) where 
%     Th is a siMesh object,
%     P  is a vector which contains the coefficients of the plane.
%
%   fc_siplt.slicemesh(Th,P,key,value,...) allows additional key/value pairs to be 
%     used when displaying the siMesh object. The key strings could be
%
%     'labels' to specify the labels of the elementary meshes. 
%              Default [] i.e all.
%     'color'  to specify the color of the displayed plane. Default is 
%              0.9*[1 1 1] (gray). 
%              If value is [] then the plane is colored with the colors 
%              of the intersected siMeshElt objects.
%
% SAMPLES
%   Th=fc_simesh.hypercube(3,10);
%   P=fc_tools.graphics.PlaneCoefs(0.5*[1 1 1],[1 -1 1]);
%   figure(1)
%   fc_siplt.slicemesh(Th,P)
%   hold on
%   fc_siplt.plot(Th,'d',1,'color','k')
%   figure(2)
%   fc_siplt.slicemesh(Th,P,'edgecolor','k','color',[])
%
%    Copyright (C) 2017-2010 F. Cuvelier
  assert(fc_simesh.is_siMesh(Th))
  assert(Th.d==3 && Th.dim==3)
  p = inputParser; 
  p.KeepUnmatched=true; 
  p.PartialMatching=false;
  p.addParamValue('labels',[]); % select labels to draw
  %p.addParamValue('color','LightGray');
  p.addParamValue('FaceColor',[]);
  p.addParamValue('EdgeColor',[]);
  p.addParamValue('merge',true,@islogical);
  p.parse(varargin{:});
  R=p.Results;
  if ~isempty(R.FaceColor), warning('Unabled ''FaceColor'' option');end  
  if ~isempty(R.EdgeColor), warning('Unabled ''EdgeColor'' option');end
  varargin=fc_tools.utils.deleteCellOptions(varargin,p.Parameters);
  %if ~isempty(R.color), varargin={varargin{:},'FaceColor',R.color};end
  if isempty(R.labels), idxlab=Th.find(3);else idxlab=Th.find(3,R.labels);end
  if isempty(idxlab), return;end
  hfig=gcf();
  PrevHold=fc_tools.graphics.SetHoldOn(true);
  if R.merge
    [q,me,toGlobal]=Th.get_mesh('labels',R.labels);
    fc_graphics4mesh.slicemesh(q,me,P,varargin{:});
  else
%    PrevHold=fc_tools.graphics.SetHoldOn(true);
%    if ~PrevHold, clf;hold on;end
    for ilab=[idxlab]
      sTh=Th.sTh{ilab};
      fc_graphics4mesh.slicemesh(sTh.q,sTh.me,P,varargin{:});%,'PlotOptions',R.PlotOptions);
    end
  end
  fc_tools.graphics.RestoreHold(PrevHold)
  figure(hfig);
end
